Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/DataTable/Simple.php')
-rw-r--r--core/DataTable/Simple.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/core/DataTable/Simple.php b/core/DataTable/Simple.php
index 7189fb0b2e..d7f9c430ad 100644
--- a/core/DataTable/Simple.php
+++ b/core/DataTable/Simple.php
@@ -8,21 +8,22 @@
* @category Piwik
* @package Piwik
*/
+namespace Piwik\DataTable;
/**
- * The DataTable_Simple is used to provide an easy way to create simple DataGrid.
- * A DataTable_Simple actually is a DataTable with 2 columns: 'label' and 'value'.
+ * The DataTable\Simple is used to provide an easy way to create simple DataGrid.
+ * A DataTable\Simple is a DataTable with 2 columns: 'label' and 'value'.
*
* It is usually best to return a DataTable_Simple instead of
* a PHP array (or other custom data structure) in API methods:
* - the generic filters can be applied automatically (offset, limit, pattern search, sort, etc.)
* - the renderer can be applied (XML, PHP, HTML, etc.)
* So you don't have to write specific renderer for your data, it is already available in all the formats supported natively by Piwik.
*
* @package Piwik
- * @subpackage Piwik_DataTable
+ * @subpackage DataTable
*/
-class Piwik_DataTable_Simple extends Piwik_DataTable
+class Simple extends DataTable
{
/**
* Loads (append) in the DataTable the array information
@@ -8,21 +8,22 @@
*
- * It is usually best to return a DataTable_Simple instead of
+ * It is usually best to return a DataTable\Simple instead of
* a PHP array (or other custom data structure) in API methods:
* - the generic filters can be applied automatically (offset, limit, pattern search, sort, etc.)